@@ -124,7 +124,8 @@
  typedef unsigned int word32;
  typedef signed int sword32;
 #else
-# error "Cannot find a 32 bit integer in your system, sorry."
+ typedef unsigned int word32; /* default */
+ typedef signed int sword32;
 #endif
 
 #if SIZEOF_UNSIGNED_INT == 2
@@ -132,13 +133,14 @@
 #elif SIZEOF_UNSIGNED_SHORT_INT == 2
  typedef unsigned short word16;
 #else 
-# error "Cannot find a 16 bit integer in your system, sorry."
+ typedef unsigned short int word16; /* default */
+ typedef signed short int sword16;
 #endif
 
 #if SIZEOF_UNSIGNED_CHAR == 1
  typedef unsigned char word8; 
 #else
-# error "Cannot find an 8 bit char in your system, sorry."
+ typedef unsigned char word8;
 #endif
 
 /* originally was defined in 3way.c */
@@ -185,6 +187,3 @@ extern char *crypt(); /* libufc */
 # define TERMIO struct sgttyb
 # define USE_SGTTY
 #endif
-
-#define CRYPT 50
-#define DES_COMPAT 51
