@@ -16,7 +16,7 @@
 
 /* Some functions that didn't fit elsewhere */
 
-/* $Id: extra.c,v 1.18 2000/03/07 12:14:42 nikos Exp $ */
+/* $Id: extra.c,v 1.19 2000/03/10 19:19:12 nikos Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -35,7 +35,7 @@
 #include "mcrypt_int.h"
 
 static char rcsid[] =
-    "$Id: extra.c,v 1.18 2000/03/07 12:14:42 nikos Exp $";
+    "$Id: extra.c,v 1.19 2000/03/10 19:19:12 nikos Exp $";
 
 extern int double_check;
 extern char *outfile;
@@ -219,7 +219,7 @@ int check_file_head(FILE * fstream, char *algorithm, char *mode,
 
 		fread(&keylen, sizeof(short int), 1, fstream);
 #ifdef WORDS_BIGENDIAN
-		*keysize = byteswap_16(keylen);
+		*keysize = byteswap16(keylen);
 #else
 		*keysize = keylen;
 #endif
@@ -227,8 +227,8 @@ int check_file_head(FILE * fstream, char *algorithm, char *mode,
 		if (strstr(algorithm, "twofish") != NULL
 		    || strstr(algorithm, "rc6") != NULL
 		    || strstr(algorithm, "blowfish") != NULL
+		    || strstr(algorithm, "rijndael") != NULL
 		    || strstr(algorithm, "rc2") != NULL
-		    || strstr(algorithm, "blowfish") != NULL
 		    || strstr(algorithm, "serpent") != NULL) {
 
 			sprintf(tmp_buf, "-%u", *keysize * 8);
@@ -376,7 +376,7 @@ int write_file_head(FILE * filedes, char *algorithm, char *mode,
 	fwrite(&null, 1, 1, filedes);
 
 #ifdef WORDS_BIGENDIAN
-	keylen = byteswap_16(keylen);
+	keylen = byteswap16(keylen);
 #endif
 	if (fwrite(&keylen, 1, sizeof(short int), filedes) !=
 	    sizeof(short int)) {
