@@ -35,17 +35,17 @@
 
 #include <defines.h>
 #include <random.h>
-#include "../libmcrypt/lib/xmemory.h"
 #include <extra.h>
+#include <xmalloc.h>
+
+#ifndef NO_GETPASS
 
 extern int noecho;
 
-static char rcsid[] = "$Id: getpass.c,v 1.1.1.1 1999/10/15 22:49:23 nmav Exp $";
+static char rcsid[] = "$Id: getpass.c,v 1.4 2000/03/07 07:16:18 nikos Exp $";
 
 /* new code, #undef if there are any problems...  */
-#define USE_SETJMP 1
-
-#ifdef USE_SETJMP
+#ifdef HAVE_SIGLONGJMP
 #include <setjmp.h>
 
 static sigjmp_buf intr;		/* where to jump on SIGINT */
@@ -61,7 +61,7 @@ static RETSIGTYPE
  sig_catch(int sig)
 {
 	sig_caught = 1;
-#ifdef USE_SETJMP
+#ifdef HAVE_SIGLONGJMP
 	siglongjmp(intr, 1);
 #endif
 }
@@ -72,7 +72,7 @@ char *
  readpass(FILE * fp)
 {
 	static char asterix[MAXLEN + 1];
-        char *input=mxmalloc(MAXLEN + 1);
+        char *input=secure_xmalloc(MAXLEN + 1);
 	char *cp, *ap, c;
 	int i;
 
@@ -134,7 +134,7 @@ char *
 char *
  readpass_old(FILE * fp)
 {
-	char* input=mxmalloc(MAXLEN + 1);
+	char* input=secure_xmalloc(MAXLEN + 1);
 	char *cp;
 
 	fflush(stderr);
@@ -198,7 +198,7 @@ char *
 		return_value = NULL;
 		goto out2;
 	}
-#ifdef USE_SETJMP
+#ifdef HAVE_SIGLONGJMP
 	/*
 	 * If we get a SIGINT, sig_catch() will jump here -
 	 * no need to press Enter after Ctrl-C.
@@ -277,3 +277,5 @@ char *
 	}
 	return return_value;
 }
+
+#endif
