@@ -24,7 +24,7 @@
  */
 
 
-/* $Id: mcrypt.c,v 1.22 2000/03/07 12:14:42 nikos Exp $ */
+/* $Id: mcrypt.c,v 1.25 2000/03/10 19:19:12 nikos Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -42,7 +42,7 @@
 
 
 static char rcsid[] =
-    "$Id: mcrypt.c,v 1.22 2000/03/07 12:14:42 nikos Exp $";
+    "$Id: mcrypt.c,v 1.25 2000/03/10 19:19:12 nikos Exp $";
 
 char tmperr[128];
 unsigned int stream_flag = FALSE;
@@ -246,7 +246,7 @@ int main(int argc, char **argv)
 	short int ein = 0, din = 0, kin = 0, force = 0, return_val = 0;
 	char *einfile = 0, *dinfile = 0, *keyword = 0;
 	char **file, **keyfile = NULL, *cfile;
-	int x, y, i, file_count = 0, keys = 0, used_algo = FALSE, v;
+	int x, y, i, file_count = 0, keys = 0, used_algo = FALSE, v, *siz;
 	gaainfo info;
 
 #ifdef HAVE_SIGNAL_H
@@ -438,7 +438,7 @@ int main(int argc, char **argv)
 		algorithm = xmalloc(strlen(info.algorithm) + 1);
 		strcpy(algorithm, info.algorithm);
 #ifndef LIBMCRYPT_22
-		i = mcrypt_is_block_algorithm(algorithm, NULL);
+		i = mcrypt_is_block_algorithm(algorithm, algorithms_directory);
 
 		if (i < 0) {
 			fprintf(stderr, _("Error in algorithm '%s'.\n"),
@@ -447,8 +447,8 @@ int main(int argc, char **argv)
 		}
 
 		if (i == 0) {
-			y = mcrypt_is_block_algorithm_mode(mode, NULL);
-			if (y > 0) {
+			y = mcrypt_is_block_algorithm_mode(mode, modes_directory);
+			if (y >= 0) {
 				mode =
 				    xrealloc(mode, strlen("stream") + 1);
 				strcpy(mode, "stream");
@@ -485,7 +485,7 @@ int main(int argc, char **argv)
 
 	if (info.mode != NULL) {
 #ifndef LIBMCRYPT_22
-		y = mcrypt_is_block_algorithm_mode(mode, NULL);
+		y = mcrypt_is_block_algorithm_mode(mode, modes_directory);
 		if (y < 0) {
 			fprintf(stderr, _("Error in mode '%s'.\n"), mode);
 			exit(1);
@@ -499,6 +499,35 @@ int main(int argc, char **argv)
 #endif
 	}
 
+#ifdef LIBMCRYPT_22
+	i = check_algo(algorithm);
+	i = keysize = mcrypt_get_key_size(i);
+
+#endif
+
+	if (info.keysize != 0) {
+#ifndef LIBMCRYPT_22
+		if (info.keysize > mcrypt_get_algo_key_size(algorithm, algorithms_directory)) {
+			err_quit(_("The specified key size is too large for this algorithm.\n"));
+		}
+
+		siz = mcrypt_get_algo_supported_key_sizes( algorithm, algorithms_directory, &i);
+		x=0;
+		for (y=0;y<i;y++) {
+			if (siz[y]==info.keysize) {
+				x=1;
+				break;
+			}
+		}
+		if (x==0) {
+			err_quit(_("The specified key size not valid for this algorithm.\n"));
+		}
+		free(siz);
+#else
+		err_warn(_("The key size parameter is ignored in that version of mcrypt.\n"));
+#endif
+
+	}
 
 	if (info.keylen != 0 && check_env() == FALSE) {
 		err_warn(_
@@ -879,13 +908,13 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 	if (keysize == 0)
 		keysize = mcrypt_get_key_size(td);
 
-	keylen = mcrypt_get_key_size(td);
+	keylen = keysize;
 	blocksize = mcrypt_get_block_size(td);
 #else
 	if (keysize == 0)
 		keysize = mcrypt_get_key_size(algo);
 
-	keylen = mcrypt_get_key_size(algo);
+	keylen = keysize;
 	blocksize = mcrypt_get_block_size(algo);
 #endif
 
@@ -1275,11 +1304,11 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		}
 		salt = xmalloc(salt_size);
 		memmove(salt, local_salt, salt_size);
-		algorithm = xmalloc(strlen(local_algorithm));
+		algorithm = xmalloc(strlen(local_algorithm)+1);
 		strcpy(algorithm, local_algorithm);
-		mode = xmalloc(strlen(local_mode));
+		mode = xmalloc(strlen(local_mode)+1);
 		strcpy(mode, local_mode);
-		keymode = xmalloc(strlen(local_keymode));
+		keymode = xmalloc(strlen(local_keymode)+1);
 		strcpy(keymode, local_keymode);
 	} else {
 		salt = NULL;
@@ -1936,15 +1965,13 @@ void print_hashlist(void)
 	int tmpi, tmpj;
 	char *tmpc;
 
-	fprintf(stdout, _("Supported Hash Algorithms:\n\n"));
+	fprintf(stdout, _("Supported Hash Algorithms:\n"));
 	for (tmpi = 0; tmpi < 256; tmpi++) {
 		tmpc = mhash_get_hash_name(tmpi);
 		if (tmpc != NULL) {
 			_tolow(tmpc, strlen(tmpc));
-			fprintf(stdout, " %s\n", tmpc);
+			fprintf(stdout, "%s\n", tmpc);
 			xfree(tmpc);
 		}
 	}
-	fprintf(stdout, "\n");
-
 }
